@@ -35,6 +35,16 @@ G_BEGIN_DECLS
 
 #define NETK_APP_WINDOW_EVENT_MASK (PropertyChangeMask | StructureNotifyMask)
 
+#define NETK_STOCK_MAXIMIZE     "gtk-zoom-100"
+#define NETK_STOCK_UNMAXIMIZE   "gtk-zoom-out"
+#define NETK_STOCK_MINIMIZE     "gtk-undo"
+#define NETK_STOCK_UNMINIMIZE   "gtk-redo"
+#define NETK_STOCK_SHADE        "gtk-goto-top"
+#define NETK_STOCK_UNSHADE      "gtk-goto-bottom"
+#define NETK_STOCK_STICK        "gtk-add"
+#define NETK_STOCK_UNSTICK      "gtk-remove"
+#define NETK_STOCK_DELETE       "gtk-close"
+
 typedef struct p_DesktopMargins
 {
     int left;
@@ -88,6 +98,7 @@ char *p_netk_get_session_id (Window xwindow);
 int p_netk_get_pid (Window xwindow);
 char *p_netk_get_name (Window xwindow);
 char *p_netk_get_res_class_utf8 (Window xwindow);
+void p_netk_get_wmclass (Window xwindow, char **res_class, char **res_name);
 
 void p_netk_select_input (Window xwindow, int mask);
 
@@ -150,5 +161,6 @@ gboolean p_netk_get_desktop_margins (Screen * xscreen,
                                      p_DesktopMargins * margins);
 void p_netk_set_desktop_margins (Window xwindow, p_DesktopMargins * margins);
 
+
 G_END_DECLS
 #endif /* NETK_XUTILS_H */
